#!/usr/bin/perl
## ######### PROJECT NAME : ##########
## 
## Lib_Auth.pm for wishmin
## 
## ######### PROJECT DESCRIPTION : ###
## 
## This file contains functions wishmin auth function
## 
## ###################################
## 
## Made by Boutonnet Alexandre
## Email   <aboutonnet@intellique.com>
## 
## Started on  Fri May 15 11:10:43 2009 Boutonnet Alexandre
## Last update Fri May 15 18:46:25 2009 Boutonnet Alexandre
## 
## ###################################
##

package Lib_Auth;

use Digest::SHA1 qw(sha1_hex);
use Tie::File;

use Data::Dumper;

my $AUTH_FILE = "etc/wishmin.passwd";
my $CHAR_SEPARATOR = ':';

sub valid_user
{
    my ($login, $passwd) = @_;

    my ($err, $err_msg) = _check_auth_file();
    return ($err, $err_msg) if ($err);

    # Opening file
    my @file;

    return (1, "Unable to open Authentification database")
	unless (tie (@file, 'Tie::File', $AUTH_FILE));

    my $found_user_flag = 0;
    my $valid_user_flag = 0;
    foreach my $line (@file)
    {
	next if ($line !~ m/^$login$CHAR_SEPARATOR.+/);
	
	# I found my user
	$found_user_flag = 1;
	my ($salt) = ($line =~ m/^$login$CHAR_SEPARATOR(.+)$CHAR_SEPARATOR.+/);

	my $passwd_hash = sha1_hex($passwd.$salt);

	$valid_user_flag = 1
	    if ($line =~ m/^$login$CHAR_SEPARATOR$salt$CHAR_SEPARATOR$passwd_hash/);
	last;
    }
    
    return (0)
	if ($found_user_flag && $valid_user_flag);
    return (1, "Authentication failed.");
}

sub insert_user
{
    my ($login, $passwd) = @_;

    # Check file access rules
    my ($err, $err_msg) = _check_auth_file();
    return ($err, $err_msg) if ($err);

    # Opening file
    my @file;

    return (1, "Unable to open Authentification database")
	unless (tie (@file, 'Tie::File', $AUTH_FILE));

    foreach my $line (@file)
    {
	return (1, "User already exists")
	    if ($line =~ m/^$login$CHAR_SEPARATOR.+/);
    }
    
    # Generating the salt
    my $salt = join '', ('.', '/', 0..9, 'A'..'Z', 'a'..'z')[rand 64, rand 64];

    # Generating the password hash
    my $passwd_hash = sha1_hex($passwd.$salt);

    push(@file, "$login"."$CHAR_SEPARATOR"."$salt"."$CHAR_SEPARATOR"."$passwd_hash");
    untie (@file);

    return (0);
}

sub _check_auth_file
{
    return (1, "Authentification database not found")
	if (! -f $AUTH_FILE);
    
    return (1, "Authentification database not readable")
	if (! -r $AUTH_FILE);
    
    return (1, "Invalid access right on the authentification database")
	if (! -O $AUTH_FILE); # || ! -G $AUTH_FILE);

    return (0);
}

1;
