## ######### PROJECT NAME : ##########
## 
## Lib_Translation.pm for wishmin
## 
## ######### PROJECT DESCRIPTION : ###
## 
## This package contains helpers to get wishmin translation
## 
## ###################################
## 
## Made by Boutonnet Alexandre
## Email   <aboutonnet@intellique.com>
## 
## Started on  Mon May 18 11:03:19 2009 Boutonnet Alexandre
## Last update Mon May 18 15:26:08 2009 Boutonnet Alexandre
## 
## ###################################
##

package Lib_Translation;

use Exporter 'import';
@EXPORT_OK = qw(Translate);

use INTLIQ::Lang;
use Lib_Log;
use HTML::Entities;

# Default language
my $DEFAULT_LANG = "en";

# Default config file
my $CONFIG_FILE = "etc/wishmin.conf";

# L'instance de l'objet
my $LANG_INSTANCE = 0;

# Le fichier de langue en cours d'utilisation
my $CURRENT_LOG_FILE = 0;


sub init
{
    my ($lang_file) = @_;

    return (0, $LANG_INSTANCE)
	if ($LANG_INSTANCE && ref($conf->{LOGGER}) eq "INTLIQ::Lang"
	    && $lang_file eq $CURRENT_LOG_FILE);

    # Obj Logger creation.
    my ($ret_val, $OBJ_LOGGER) = Lib_Log::get_obj_instance();
    Lib_CGI::send_critical_header("OBJ_LOGGER : ".$OBJ_LOGGER)
	if ($ret_val);

    my $OBJ_LANG;
    ($ret_val, $OBJ_LANG) = new INTLIQ::Lang("etc/lang/", $lang_file, _get_lang_to_use(), $OBJ_LOGGER);
    Lib_CGI::send_critical_header("OBJ_LANG : ".$OBJ_LANG)
	if ($ret_val);

    $CURRENT_LOG_FILE = $lang_file;
    $LANG_INSTANCE = $OBJ_LANG;
}

sub Translate
{
    my $key = shift;

    Lib_CGI::send_critical_header("Unable to find Translation Object Instance")
	if (!$LANG_INSTANCE || ref($conf->{LOGGER}) eq "INTLIQ::Lang");
    
    my $msg = '-----';
    if (scalar(@_))
    {
	(undef, $msg) = $LANG_INSTANCE->get_msg_with_section($key, @_);
    }
    else
    {
	(undef, $msg) = $LANG_INSTANCE->get_msg($key, @_);
    }

    return (encode_entities($msg));
}

sub _get_lang_to_use
{
    my $used_lang = `grep -v -e "^#" $CONFIG_FILE | grep lang | cut -f 2 -d '='`;

    return ($DEFAULT_LANG) if (!$used_lang);
    
    chomp $used_lang;
    $used_lang =~ s/ //g if ($used_lang =~ m/^\s*[\D\/]+/);
    
    return ($used_lang);
}

1;
